from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.auth_method import AuthMethod
from ..models.user_role import UserRole
from ..types import UNSET, Unset

T = TypeVar("T", bound="UserCreate")


@_attrs_define
class UserCreate:
    """
    Attributes:
        email (str):
        auth_method (Union[Unset, AuthMethod]):
        email_is_verified (Union[None, Unset, bool]):  Default: False.
        first_name (Union[None, Unset, str]):  Default: ''.
        last_name (Union[None, Unset, str]):  Default: ''.
        password (Union[None, Unset, str]):
        role (Union[Unset, UserRole]):
    """

    email: str
    auth_method: Union[Unset, AuthMethod] = UNSET
    email_is_verified: Union[None, Unset, bool] = False
    first_name: Union[None, Unset, str] = ""
    last_name: Union[None, Unset, str] = ""
    password: Union[None, Unset, str] = UNSET
    role: Union[Unset, UserRole] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        email = self.email

        auth_method: Union[Unset, str] = UNSET
        if not isinstance(self.auth_method, Unset):
            auth_method = self.auth_method.value

        email_is_verified: Union[None, Unset, bool]
        if isinstance(self.email_is_verified, Unset):
            email_is_verified = UNSET
        else:
            email_is_verified = self.email_is_verified

        first_name: Union[None, Unset, str]
        if isinstance(self.first_name, Unset):
            first_name = UNSET
        else:
            first_name = self.first_name

        last_name: Union[None, Unset, str]
        if isinstance(self.last_name, Unset):
            last_name = UNSET
        else:
            last_name = self.last_name

        password: Union[None, Unset, str]
        if isinstance(self.password, Unset):
            password = UNSET
        else:
            password = self.password

        role: Union[Unset, str] = UNSET
        if not isinstance(self.role, Unset):
            role = self.role.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"email": email})
        if auth_method is not UNSET:
            field_dict["auth_method"] = auth_method
        if email_is_verified is not UNSET:
            field_dict["email_is_verified"] = email_is_verified
        if first_name is not UNSET:
            field_dict["first_name"] = first_name
        if last_name is not UNSET:
            field_dict["last_name"] = last_name
        if password is not UNSET:
            field_dict["password"] = password
        if role is not UNSET:
            field_dict["role"] = role

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        email = d.pop("email")

        _auth_method = d.pop("auth_method", UNSET)
        auth_method: Union[Unset, AuthMethod]
        if isinstance(_auth_method, Unset):
            auth_method = UNSET
        else:
            auth_method = AuthMethod(_auth_method)

        def _parse_email_is_verified(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        email_is_verified = _parse_email_is_verified(d.pop("email_is_verified", UNSET))

        def _parse_first_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        first_name = _parse_first_name(d.pop("first_name", UNSET))

        def _parse_last_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        last_name = _parse_last_name(d.pop("last_name", UNSET))

        def _parse_password(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        password = _parse_password(d.pop("password", UNSET))

        _role = d.pop("role", UNSET)
        role: Union[Unset, UserRole]
        if isinstance(_role, Unset):
            role = UNSET
        else:
            role = UserRole(_role)

        user_create = cls(
            email=email,
            auth_method=auth_method,
            email_is_verified=email_is_verified,
            first_name=first_name,
            last_name=last_name,
            password=password,
            role=role,
        )

        user_create.additional_properties = d
        return user_create

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..models.model_kind import ModelKind
from ..models.model_upload_status import ModelUploadStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.training_model_response_parameters import TrainingModelResponseParameters


T = TypeVar("T", bound="TrainingModelResponse")


@_attrs_define
class TrainingModelResponse:
    """
    Attributes:
        id (str):
        kind (ModelKind):
        parameters (TrainingModelResponseParameters):
        project_id (str):
        project_name (str):
        run_id (str):
        run_name (str):
        filename (Union[None, Unset, str]):
        storage_url (Union[None, Unset, str]):
        upload_status (Union[Unset, ModelUploadStatus]):
    """

    id: str
    kind: ModelKind
    parameters: "TrainingModelResponseParameters"
    project_id: str
    project_name: str
    run_id: str
    run_name: str
    filename: Union[None, Unset, str] = UNSET
    storage_url: Union[None, Unset, str] = UNSET
    upload_status: Union[Unset, ModelUploadStatus] = UNSET

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        kind = self.kind.value

        parameters = self.parameters.to_dict()

        project_id = self.project_id

        project_name = self.project_name

        run_id = self.run_id

        run_name = self.run_name

        filename: Union[None, Unset, str]
        if isinstance(self.filename, Unset):
            filename = UNSET
        else:
            filename = self.filename

        storage_url: Union[None, Unset, str]
        if isinstance(self.storage_url, Unset):
            storage_url = UNSET
        else:
            storage_url = self.storage_url

        upload_status: Union[Unset, str] = UNSET
        if not isinstance(self.upload_status, Unset):
            upload_status = self.upload_status.value

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "id": id,
                "kind": kind,
                "parameters": parameters,
                "project_id": project_id,
                "project_name": project_name,
                "run_id": run_id,
                "run_name": run_name,
            }
        )
        if filename is not UNSET:
            field_dict["filename"] = filename
        if storage_url is not UNSET:
            field_dict["storage_url"] = storage_url
        if upload_status is not UNSET:
            field_dict["upload_status"] = upload_status

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.training_model_response_parameters import TrainingModelResponseParameters

        d = src_dict.copy()
        id = d.pop("id")

        kind = ModelKind(d.pop("kind"))

        parameters = TrainingModelResponseParameters.from_dict(d.pop("parameters"))

        project_id = d.pop("project_id")

        project_name = d.pop("project_name")

        run_id = d.pop("run_id")

        run_name = d.pop("run_name")

        def _parse_filename(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        filename = _parse_filename(d.pop("filename", UNSET))

        def _parse_storage_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        storage_url = _parse_storage_url(d.pop("storage_url", UNSET))

        _upload_status = d.pop("upload_status", UNSET)
        upload_status: Union[Unset, ModelUploadStatus]
        if isinstance(_upload_status, Unset):
            upload_status = UNSET
        else:
            upload_status = ModelUploadStatus(_upload_status)

        training_model_response = cls(
            id=id,
            kind=kind,
            parameters=parameters,
            project_id=project_id,
            project_name=project_name,
            run_id=run_id,
            run_name=run_name,
            filename=filename,
            storage_url=storage_url,
            upload_status=upload_status,
        )

        return training_model_response



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.scorer_defaults import ScorerDefaults


T = TypeVar("T", bound="UpdateScorerRequest")


@_attrs_define
class UpdateScorerRequest:
    """
    Attributes:
        defaults (Union['ScorerDefaults', None, Unset]):
        description (Union[None, Unset, str]):
        name (Union[None, Unset, str]):
        tags (Union[None, Unset, list[str]]):
    """

    defaults: Union["ScorerDefaults", None, Unset] = UNSET
    description: Union[None, Unset, str] = UNSET
    name: Union[None, Unset, str] = UNSET
    tags: Union[None, Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.scorer_defaults import ScorerDefaults

        defaults: Union[None, Unset, dict[str, Any]]
        if isinstance(self.defaults, Unset):
            defaults = UNSET
        elif isinstance(self.defaults, ScorerDefaults):
            defaults = self.defaults.to_dict()
        else:
            defaults = self.defaults

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        name: Union[None, Unset, str]
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        tags: Union[None, Unset, list[str]]
        if isinstance(self.tags, Unset):
            tags = UNSET
        elif isinstance(self.tags, list):
            tags = self.tags

        else:
            tags = self.tags

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if defaults is not UNSET:
            field_dict["defaults"] = defaults
        if description is not UNSET:
            field_dict["description"] = description
        if name is not UNSET:
            field_dict["name"] = name
        if tags is not UNSET:
            field_dict["tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.scorer_defaults import ScorerDefaults

        d = src_dict.copy()

        def _parse_defaults(data: object) -> Union["ScorerDefaults", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                defaults_type_0 = ScorerDefaults.from_dict(data)

                return defaults_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ScorerDefaults", None, Unset], data)

        defaults = _parse_defaults(d.pop("defaults", UNSET))

        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name = _parse_name(d.pop("name", UNSET))

        def _parse_tags(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                tags_type_0 = cast(list[str], data)

                return tags_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        tags = _parse_tags(d.pop("tags", UNSET))

        update_scorer_request = cls(defaults=defaults, description=description, name=name, tags=tags)

        update_scorer_request.additional_properties = d
        return update_scorer_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Literal, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.azure_authentication_type import AzureAuthenticationType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.azure_integration_extra_type_0 import AzureIntegrationExtraType0
    from ..models.azure_integration_headers_type_0 import AzureIntegrationHeadersType0
    from ..models.azure_model_deployment import AzureModelDeployment


T = TypeVar("T", bound="AzureIntegration")


@_attrs_define
class AzureIntegration:
    """
    Attributes:
        endpoint (str):
        api_version (Union[Unset, str]):  Default: '2024-10-21'.
        authentication_scope (Union[None, Unset, str]):
        authentication_type (Union[Unset, AzureAuthenticationType]):
        available_deployments (Union[None, Unset, list['AzureModelDeployment']]): The available deployments for this
            integration. If provided, we will not try to get this list from Azure.
        azure_deployment (Union[None, Unset, str]):
        extra (Union['AzureIntegrationExtraType0', None, Unset]):
        headers (Union['AzureIntegrationHeadersType0', None, Unset]):
        name (Union[Literal['azure'], Unset]):  Default: 'azure'.
        proxy (Union[Unset, bool]):  Default: False.
    """

    endpoint: str
    api_version: Union[Unset, str] = "2024-10-21"
    authentication_scope: Union[None, Unset, str] = UNSET
    authentication_type: Union[Unset, AzureAuthenticationType] = UNSET
    available_deployments: Union[None, Unset, list["AzureModelDeployment"]] = UNSET
    azure_deployment: Union[None, Unset, str] = UNSET
    extra: Union["AzureIntegrationExtraType0", None, Unset] = UNSET
    headers: Union["AzureIntegrationHeadersType0", None, Unset] = UNSET
    name: Union[Literal["azure"], Unset] = "azure"
    proxy: Union[Unset, bool] = False
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.azure_integration_extra_type_0 import AzureIntegrationExtraType0
        from ..models.azure_integration_headers_type_0 import AzureIntegrationHeadersType0

        endpoint = self.endpoint

        api_version = self.api_version

        authentication_scope: Union[None, Unset, str]
        if isinstance(self.authentication_scope, Unset):
            authentication_scope = UNSET
        else:
            authentication_scope = self.authentication_scope

        authentication_type: Union[Unset, str] = UNSET
        if not isinstance(self.authentication_type, Unset):
            authentication_type = self.authentication_type.value

        available_deployments: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.available_deployments, Unset):
            available_deployments = UNSET
        elif isinstance(self.available_deployments, list):
            available_deployments = []
            for available_deployments_type_0_item_data in self.available_deployments:
                available_deployments_type_0_item = available_deployments_type_0_item_data.to_dict()
                available_deployments.append(available_deployments_type_0_item)

        else:
            available_deployments = self.available_deployments

        azure_deployment: Union[None, Unset, str]
        if isinstance(self.azure_deployment, Unset):
            azure_deployment = UNSET
        else:
            azure_deployment = self.azure_deployment

        extra: Union[None, Unset, dict[str, Any]]
        if isinstance(self.extra, Unset):
            extra = UNSET
        elif isinstance(self.extra, AzureIntegrationExtraType0):
            extra = self.extra.to_dict()
        else:
            extra = self.extra

        headers: Union[None, Unset, dict[str, Any]]
        if isinstance(self.headers, Unset):
            headers = UNSET
        elif isinstance(self.headers, AzureIntegrationHeadersType0):
            headers = self.headers.to_dict()
        else:
            headers = self.headers

        name = self.name

        proxy = self.proxy

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"endpoint": endpoint})
        if api_version is not UNSET:
            field_dict["api_version"] = api_version
        if authentication_scope is not UNSET:
            field_dict["authentication_scope"] = authentication_scope
        if authentication_type is not UNSET:
            field_dict["authentication_type"] = authentication_type
        if available_deployments is not UNSET:
            field_dict["available_deployments"] = available_deployments
        if azure_deployment is not UNSET:
            field_dict["azure_deployment"] = azure_deployment
        if extra is not UNSET:
            field_dict["extra"] = extra
        if headers is not UNSET:
            field_dict["headers"] = headers
        if name is not UNSET:
            field_dict["name"] = name
        if proxy is not UNSET:
            field_dict["proxy"] = proxy

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.azure_integration_extra_type_0 import AzureIntegrationExtraType0
        from ..models.azure_integration_headers_type_0 import AzureIntegrationHeadersType0
        from ..models.azure_model_deployment import AzureModelDeployment

        d = src_dict.copy()
        endpoint = d.pop("endpoint")

        api_version = d.pop("api_version", UNSET)

        def _parse_authentication_scope(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        authentication_scope = _parse_authentication_scope(d.pop("authentication_scope", UNSET))

        _authentication_type = d.pop("authentication_type", UNSET)
        authentication_type: Union[Unset, AzureAuthenticationType]
        if isinstance(_authentication_type, Unset):
            authentication_type = UNSET
        else:
            authentication_type = AzureAuthenticationType(_authentication_type)

        def _parse_available_deployments(data: object) -> Union[None, Unset, list["AzureModelDeployment"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                available_deployments_type_0 = []
                _available_deployments_type_0 = data
                for available_deployments_type_0_item_data in _available_deployments_type_0:
                    available_deployments_type_0_item = AzureModelDeployment.from_dict(
                        available_deployments_type_0_item_data
                    )

                    available_deployments_type_0.append(available_deployments_type_0_item)

                return available_deployments_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["AzureModelDeployment"]], data)

        available_deployments = _parse_available_deployments(d.pop("available_deployments", UNSET))

        def _parse_azure_deployment(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        azure_deployment = _parse_azure_deployment(d.pop("azure_deployment", UNSET))

        def _parse_extra(data: object) -> Union["AzureIntegrationExtraType0", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                extra_type_0 = AzureIntegrationExtraType0.from_dict(data)

                return extra_type_0
            except:  # noqa: E722
                pass
            return cast(Union["AzureIntegrationExtraType0", None, Unset], data)

        extra = _parse_extra(d.pop("extra", UNSET))

        def _parse_headers(data: object) -> Union["AzureIntegrationHeadersType0", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                headers_type_0 = AzureIntegrationHeadersType0.from_dict(data)

                return headers_type_0
            except:  # noqa: E722
                pass
            return cast(Union["AzureIntegrationHeadersType0", None, Unset], data)

        headers = _parse_headers(d.pop("headers", UNSET))

        name = cast(Union[Literal["azure"], Unset], d.pop("name", UNSET))
        if name != "azure" and not isinstance(name, Unset):
            raise ValueError(f"name must match const 'azure', got '{name}'")

        proxy = d.pop("proxy", UNSET)

        azure_integration = cls(
            endpoint=endpoint,
            api_version=api_version,
            authentication_scope=authentication_scope,
            authentication_type=authentication_type,
            available_deployments=available_deployments,
            azure_deployment=azure_deployment,
            extra=extra,
            headers=headers,
            name=name,
            proxy=proxy,
        )

        azure_integration.additional_properties = d
        return azure_integration

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.noise_type import NoiseType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.b_box import BBox
    from ..models.data_row_meta_type_0 import DataRowMetaType0
    from ..models.data_row_system_prompts_type_0 import DataRowSystemPromptsType0
    from ..models.polygon_data import PolygonData
    from ..models.seq_2_seq_segment import Seq2SeqSegment
    from ..models.span import Span


T = TypeVar("T", bound="DataRow")


@_attrs_define
class DataRow:
    """
    Attributes:
        id (int):
        background (Union[None, Unset, int]):
        bleu (Union[None, Unset, float]):
        boundary_iou (Union[None, Unset, float]):
        boxes (Union[None, Unset, list['BBox']]):
        classification (Union[None, Unset, int]):
        classification_and_localization (Union[None, Unset, int]):
        confidence (Union[None, Unset, float]):
        data_error_potential (Union[None, Unset, float]):
        dep_mask (Union[None, Unset, str]):
        drift_score (Union[None, Unset, float]):
        duplicate (Union[None, Unset, int]):
        edit_relabeled (Union[Unset, bool]):  Default: False.
        edited (Union[Unset, bool]):  Default: False.
        generated_output (Union[None, Unset, str]):
        generated_segments (Union[None, Unset, list['Seq2SeqSegment']]):
        generated_uncertainty (Union[None, Unset, float]):
        ghost_span (Union[None, Unset, int]):
        gold (Union[None, Unset, str]):
        height (Union[None, Unset, int]):
        image (Union[None, Unset, str]):  Default: ''.
        input_ (Union[None, Unset, str]):
        input_cutoff (Union[None, Unset, int]):
        is_drifted (Union[None, Unset, bool]):
        is_on_the_boundary (Union[None, Unset, bool]):
        localization (Union[None, Unset, int]):
        max_dep (Union[None, Unset, float]):
        max_dep_label (Union[None, Unset, str]):
        mean_iou (Union[None, Unset, float]):
        meta (Union['DataRowMetaType0', None, Unset]):
        missed (Union[None, Unset, int]):
        missed_label (Union[None, Unset, int]):
        mltc_golds (Union[None, Unset, list[str]]):
        mltc_golds_deps (Union[None, Unset, list[float]]):
        mltc_preds (Union[None, Unset, list[str]]):
        mltc_preds_deps (Union[None, Unset, list[float]]):
        noise_type (Union[NoiseType, None, Unset]):
        perplexity (Union[None, Unset, float]):
        polygons (Union[None, Unset, list['PolygonData']]):
        pred (Union[None, Unset, str]):
        rouge (Union[None, Unset, float]):
        span_shift (Union[None, Unset, int]):
        spans (Union[None, Unset, list['Span']]):
        system_prompts (Union['DataRowSystemPromptsType0', None, Unset]):
        target (Union[None, Unset, str]):
        target_cutoff (Union[None, Unset, int]):
        target_segments (Union[None, Unset, list['Seq2SeqSegment']]):
        text (Union[None, Unset, str]):  Default: ''.
        total_errors (Union[None, Unset, int]):
        width (Union[None, Unset, int]):
        wrong_tag (Union[None, Unset, int]):
        x (Union[None, Unset, float]):
        y (Union[None, Unset, float]):
    """

    id: int
    background: Union[None, Unset, int] = UNSET
    bleu: Union[None, Unset, float] = UNSET
    boundary_iou: Union[None, Unset, float] = UNSET
    boxes: Union[None, Unset, list["BBox"]] = UNSET
    classification: Union[None, Unset, int] = UNSET
    classification_and_localization: Union[None, Unset, int] = UNSET
    confidence: Union[None, Unset, float] = UNSET
    data_error_potential: Union[None, Unset, float] = UNSET
    dep_mask: Union[None, Unset, str] = UNSET
    drift_score: Union[None, Unset, float] = UNSET
    duplicate: Union[None, Unset, int] = UNSET
    edit_relabeled: Union[Unset, bool] = False
    edited: Union[Unset, bool] = False
    generated_output: Union[None, Unset, str] = UNSET
    generated_segments: Union[None, Unset, list["Seq2SeqSegment"]] = UNSET
    generated_uncertainty: Union[None, Unset, float] = UNSET
    ghost_span: Union[None, Unset, int] = UNSET
    gold: Union[None, Unset, str] = UNSET
    height: Union[None, Unset, int] = UNSET
    image: Union[None, Unset, str] = ""
    input_: Union[None, Unset, str] = UNSET
    input_cutoff: Union[None, Unset, int] = UNSET
    is_drifted: Union[None, Unset, bool] = UNSET
    is_on_the_boundary: Union[None, Unset, bool] = UNSET
    localization: Union[None, Unset, int] = UNSET
    max_dep: Union[None, Unset, float] = UNSET
    max_dep_label: Union[None, Unset, str] = UNSET
    mean_iou: Union[None, Unset, float] = UNSET
    meta: Union["DataRowMetaType0", None, Unset] = UNSET
    missed: Union[None, Unset, int] = UNSET
    missed_label: Union[None, Unset, int] = UNSET
    mltc_golds: Union[None, Unset, list[str]] = UNSET
    mltc_golds_deps: Union[None, Unset, list[float]] = UNSET
    mltc_preds: Union[None, Unset, list[str]] = UNSET
    mltc_preds_deps: Union[None, Unset, list[float]] = UNSET
    noise_type: Union[NoiseType, None, Unset] = UNSET
    perplexity: Union[None, Unset, float] = UNSET
    polygons: Union[None, Unset, list["PolygonData"]] = UNSET
    pred: Union[None, Unset, str] = UNSET
    rouge: Union[None, Unset, float] = UNSET
    span_shift: Union[None, Unset, int] = UNSET
    spans: Union[None, Unset, list["Span"]] = UNSET
    system_prompts: Union["DataRowSystemPromptsType0", None, Unset] = UNSET
    target: Union[None, Unset, str] = UNSET
    target_cutoff: Union[None, Unset, int] = UNSET
    target_segments: Union[None, Unset, list["Seq2SeqSegment"]] = UNSET
    text: Union[None, Unset, str] = ""
    total_errors: Union[None, Unset, int] = UNSET
    width: Union[None, Unset, int] = UNSET
    wrong_tag: Union[None, Unset, int] = UNSET
    x: Union[None, Unset, float] = UNSET
    y: Union[None, Unset, float] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.data_row_meta_type_0 import DataRowMetaType0
        from ..models.data_row_system_prompts_type_0 import DataRowSystemPromptsType0

        id = self.id

        background: Union[None, Unset, int]
        if isinstance(self.background, Unset):
            background = UNSET
        else:
            background = self.background

        bleu: Union[None, Unset, float]
        if isinstance(self.bleu, Unset):
            bleu = UNSET
        else:
            bleu = self.bleu

        boundary_iou: Union[None, Unset, float]
        if isinstance(self.boundary_iou, Unset):
            boundary_iou = UNSET
        else:
            boundary_iou = self.boundary_iou

        boxes: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.boxes, Unset):
            boxes = UNSET
        elif isinstance(self.boxes, list):
            boxes = []
            for boxes_type_0_item_data in self.boxes:
                boxes_type_0_item = boxes_type_0_item_data.to_dict()
                boxes.append(boxes_type_0_item)

        else:
            boxes = self.boxes

        classification: Union[None, Unset, int]
        if isinstance(self.classification, Unset):
            classification = UNSET
        else:
            classification = self.classification

        classification_and_localization: Union[None, Unset, int]
        if isinstance(self.classification_and_localization, Unset):
            classification_and_localization = UNSET
        else:
            classification_and_localization = self.classification_and_localization

        confidence: Union[None, Unset, float]
        if isinstance(self.confidence, Unset):
            confidence = UNSET
        else:
            confidence = self.confidence

        data_error_potential: Union[None, Unset, float]
        if isinstance(self.data_error_potential, Unset):
            data_error_potential = UNSET
        else:
            data_error_potential = self.data_error_potential

        dep_mask: Union[None, Unset, str]
        if isinstance(self.dep_mask, Unset):
            dep_mask = UNSET
        else:
            dep_mask = self.dep_mask

        drift_score: Union[None, Unset, float]
        if isinstance(self.drift_score, Unset):
            drift_score = UNSET
        else:
            drift_score = self.drift_score

        duplicate: Union[None, Unset, int]
        if isinstance(self.duplicate, Unset):
            duplicate = UNSET
        else:
            duplicate = self.duplicate

        edit_relabeled = self.edit_relabeled

        edited = self.edited

        generated_output: Union[None, Unset, str]
        if isinstance(self.generated_output, Unset):
            generated_output = UNSET
        else:
            generated_output = self.generated_output

        generated_segments: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.generated_segments, Unset):
            generated_segments = UNSET
        elif isinstance(self.generated_segments, list):
            generated_segments = []
            for generated_segments_type_0_item_data in self.generated_segments:
                generated_segments_type_0_item = generated_segments_type_0_item_data.to_dict()
                generated_segments.append(generated_segments_type_0_item)

        else:
            generated_segments = self.generated_segments

        generated_uncertainty: Union[None, Unset, float]
        if isinstance(self.generated_uncertainty, Unset):
            generated_uncertainty = UNSET
        else:
            generated_uncertainty = self.generated_uncertainty

        ghost_span: Union[None, Unset, int]
        if isinstance(self.ghost_span, Unset):
            ghost_span = UNSET
        else:
            ghost_span = self.ghost_span

        gold: Union[None, Unset, str]
        if isinstance(self.gold, Unset):
            gold = UNSET
        else:
            gold = self.gold

        height: Union[None, Unset, int]
        if isinstance(self.height, Unset):
            height = UNSET
        else:
            height = self.height

        image: Union[None, Unset, str]
        if isinstance(self.image, Unset):
            image = UNSET
        else:
            image = self.image

        input_: Union[None, Unset, str]
        if isinstance(self.input_, Unset):
            input_ = UNSET
        else:
            input_ = self.input_

        input_cutoff: Union[None, Unset, int]
        if isinstance(self.input_cutoff, Unset):
            input_cutoff = UNSET
        else:
            input_cutoff = self.input_cutoff

        is_drifted: Union[None, Unset, bool]
        if isinstance(self.is_drifted, Unset):
            is_drifted = UNSET
        else:
            is_drifted = self.is_drifted

        is_on_the_boundary: Union[None, Unset, bool]
        if isinstance(self.is_on_the_boundary, Unset):
            is_on_the_boundary = UNSET
        else:
            is_on_the_boundary = self.is_on_the_boundary

        localization: Union[None, Unset, int]
        if isinstance(self.localization, Unset):
            localization = UNSET
        else:
            localization = self.localization

        max_dep: Union[None, Unset, float]
        if isinstance(self.max_dep, Unset):
            max_dep = UNSET
        else:
            max_dep = self.max_dep

        max_dep_label: Union[None, Unset, str]
        if isinstance(self.max_dep_label, Unset):
            max_dep_label = UNSET
        else:
            max_dep_label = self.max_dep_label

        mean_iou: Union[None, Unset, float]
        if isinstance(self.mean_iou, Unset):
            mean_iou = UNSET
        else:
            mean_iou = self.mean_iou

        meta: Union[None, Unset, dict[str, Any]]
        if isinstance(self.meta, Unset):
            meta = UNSET
        elif isinstance(self.meta, DataRowMetaType0):
            meta = self.meta.to_dict()
        else:
            meta = self.meta

        missed: Union[None, Unset, int]
        if isinstance(self.missed, Unset):
            missed = UNSET
        else:
            missed = self.missed

        missed_label: Union[None, Unset, int]
        if isinstance(self.missed_label, Unset):
            missed_label = UNSET
        else:
            missed_label = self.missed_label

        mltc_golds: Union[None, Unset, list[str]]
        if isinstance(self.mltc_golds, Unset):
            mltc_golds = UNSET
        elif isinstance(self.mltc_golds, list):
            mltc_golds = self.mltc_golds

        else:
            mltc_golds = self.mltc_golds

        mltc_golds_deps: Union[None, Unset, list[float]]
        if isinstance(self.mltc_golds_deps, Unset):
            mltc_golds_deps = UNSET
        elif isinstance(self.mltc_golds_deps, list):
            mltc_golds_deps = self.mltc_golds_deps

        else:
            mltc_golds_deps = self.mltc_golds_deps

        mltc_preds: Union[None, Unset, list[str]]
        if isinstance(self.mltc_preds, Unset):
            mltc_preds = UNSET
        elif isinstance(self.mltc_preds, list):
            mltc_preds = self.mltc_preds

        else:
            mltc_preds = self.mltc_preds

        mltc_preds_deps: Union[None, Unset, list[float]]
        if isinstance(self.mltc_preds_deps, Unset):
            mltc_preds_deps = UNSET
        elif isinstance(self.mltc_preds_deps, list):
            mltc_preds_deps = self.mltc_preds_deps

        else:
            mltc_preds_deps = self.mltc_preds_deps

        noise_type: Union[None, Unset, str]
        if isinstance(self.noise_type, Unset):
            noise_type = UNSET
        elif isinstance(self.noise_type, NoiseType):
            noise_type = self.noise_type.value
        else:
            noise_type = self.noise_type

        perplexity: Union[None, Unset, float]
        if isinstance(self.perplexity, Unset):
            perplexity = UNSET
        else:
            perplexity = self.perplexity

        polygons: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.polygons, Unset):
            polygons = UNSET
        elif isinstance(self.polygons, list):
            polygons = []
            for polygons_type_0_item_data in self.polygons:
                polygons_type_0_item = polygons_type_0_item_data.to_dict()
                polygons.append(polygons_type_0_item)

        else:
            polygons = self.polygons

        pred: Union[None, Unset, str]
        if isinstance(self.pred, Unset):
            pred = UNSET
        else:
            pred = self.pred

        rouge: Union[None, Unset, float]
        if isinstance(self.rouge, Unset):
            rouge = UNSET
        else:
            rouge = self.rouge

        span_shift: Union[None, Unset, int]
        if isinstance(self.span_shift, Unset):
            span_shift = UNSET
        else:
            span_shift = self.span_shift

        spans: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.spans, Unset):
            spans = UNSET
        elif isinstance(self.spans, list):
            spans = []
            for spans_type_0_item_data in self.spans:
                spans_type_0_item = spans_type_0_item_data.to_dict()
                spans.append(spans_type_0_item)

        else:
            spans = self.spans

        system_prompts: Union[None, Unset, dict[str, Any]]
        if isinstance(self.system_prompts, Unset):
            system_prompts = UNSET
        elif isinstance(self.system_prompts, DataRowSystemPromptsType0):
            system_prompts = self.system_prompts.to_dict()
        else:
            system_prompts = self.system_prompts

        target: Union[None, Unset, str]
        if isinstance(self.target, Unset):
            target = UNSET
        else:
            target = self.target

        target_cutoff: Union[None, Unset, int]
        if isinstance(self.target_cutoff, Unset):
            target_cutoff = UNSET
        else:
            target_cutoff = self.target_cutoff

        target_segments: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.target_segments, Unset):
            target_segments = UNSET
        elif isinstance(self.target_segments, list):
            target_segments = []
            for target_segments_type_0_item_data in self.target_segments:
                target_segments_type_0_item = target_segments_type_0_item_data.to_dict()
                target_segments.append(target_segments_type_0_item)

        else:
            target_segments = self.target_segments

        text: Union[None, Unset, str]
        if isinstance(self.text, Unset):
            text = UNSET
        else:
            text = self.text

        total_errors: Union[None, Unset, int]
        if isinstance(self.total_errors, Unset):
            total_errors = UNSET
        else:
            total_errors = self.total_errors

        width: Union[None, Unset, int]
        if isinstance(self.width, Unset):
            width = UNSET
        else:
            width = self.width

        wrong_tag: Union[None, Unset, int]
        if isinstance(self.wrong_tag, Unset):
            wrong_tag = UNSET
        else:
            wrong_tag = self.wrong_tag

        x: Union[None, Unset, float]
        if isinstance(self.x, Unset):
            x = UNSET
        else:
            x = self.x

        y: Union[None, Unset, float]
        if isinstance(self.y, Unset):
            y = UNSET
        else:
            y = self.y

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"id": id})
        if background is not UNSET:
            field_dict["background"] = background
        if bleu is not UNSET:
            field_dict["bleu"] = bleu
        if boundary_iou is not UNSET:
            field_dict["boundary_iou"] = boundary_iou
        if boxes is not UNSET:
            field_dict["boxes"] = boxes
        if classification is not UNSET:
            field_dict["classification"] = classification
        if classification_and_localization is not UNSET:
            field_dict["classification_and_localization"] = classification_and_localization
        if confidence is not UNSET:
            field_dict["confidence"] = confidence
        if data_error_potential is not UNSET:
            field_dict["data_error_potential"] = data_error_potential
        if dep_mask is not UNSET:
            field_dict["dep_mask"] = dep_mask
        if drift_score is not UNSET:
            field_dict["drift_score"] = drift_score
        if duplicate is not UNSET:
            field_dict["duplicate"] = duplicate
        if edit_relabeled is not UNSET:
            field_dict["edit_relabeled"] = edit_relabeled
        if edited is not UNSET:
            field_dict["edited"] = edited
        if generated_output is not UNSET:
            field_dict["generated_output"] = generated_output
        if generated_segments is not UNSET:
            field_dict["generated_segments"] = generated_segments
        if generated_uncertainty is not UNSET:
            field_dict["generated_uncertainty"] = generated_uncertainty
        if ghost_span is not UNSET:
            field_dict["ghost_span"] = ghost_span
        if gold is not UNSET:
            field_dict["gold"] = gold
        if height is not UNSET:
            field_dict["height"] = height
        if image is not UNSET:
            field_dict["image"] = image
        if input_ is not UNSET:
            field_dict["input"] = input_
        if input_cutoff is not UNSET:
            field_dict["input_cutoff"] = input_cutoff
        if is_drifted is not UNSET:
            field_dict["is_drifted"] = is_drifted
        if is_on_the_boundary is not UNSET:
            field_dict["is_on_the_boundary"] = is_on_the_boundary
        if localization is not UNSET:
            field_dict["localization"] = localization
        if max_dep is not UNSET:
            field_dict["max_dep"] = max_dep
        if max_dep_label is not UNSET:
            field_dict["max_dep_label"] = max_dep_label
        if mean_iou is not UNSET:
            field_dict["mean_iou"] = mean_iou
        if meta is not UNSET:
            field_dict["meta"] = meta
        if missed is not UNSET:
            field_dict["missed"] = missed
        if missed_label is not UNSET:
            field_dict["missed_label"] = missed_label
        if mltc_golds is not UNSET:
            field_dict["mltc_golds"] = mltc_golds
        if mltc_golds_deps is not UNSET:
            field_dict["mltc_golds_deps"] = mltc_golds_deps
        if mltc_preds is not UNSET:
            field_dict["mltc_preds"] = mltc_preds
        if mltc_preds_deps is not UNSET:
            field_dict["mltc_preds_deps"] = mltc_preds_deps
        if noise_type is not UNSET:
            field_dict["noise_type"] = noise_type
        if perplexity is not UNSET:
            field_dict["perplexity"] = perplexity
        if polygons is not UNSET:
            field_dict["polygons"] = polygons
        if pred is not UNSET:
            field_dict["pred"] = pred
        if rouge is not UNSET:
            field_dict["rouge"] = rouge
        if span_shift is not UNSET:
            field_dict["span_shift"] = span_shift
        if spans is not UNSET:
            field_dict["spans"] = spans
        if system_prompts is not UNSET:
            field_dict["system_prompts"] = system_prompts
        if target is not UNSET:
            field_dict["target"] = target
        if target_cutoff is not UNSET:
            field_dict["target_cutoff"] = target_cutoff
        if target_segments is not UNSET:
            field_dict["target_segments"] = target_segments
        if text is not UNSET:
            field_dict["text"] = text
        if total_errors is not UNSET:
            field_dict["total_errors"] = total_errors
        if width is not UNSET:
            field_dict["width"] = width
        if wrong_tag is not UNSET:
            field_dict["wrong_tag"] = wrong_tag
        if x is not UNSET:
            field_dict["x"] = x
        if y is not UNSET:
            field_dict["y"] = y

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.b_box import BBox
        from ..models.data_row_meta_type_0 import DataRowMetaType0
        from ..models.data_row_system_prompts_type_0 import DataRowSystemPromptsType0
        from ..models.polygon_data import PolygonData
        from ..models.seq_2_seq_segment import Seq2SeqSegment
        from ..models.span import Span

        d = src_dict.copy()
        id = d.pop("id")

        def _parse_background(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        background = _parse_background(d.pop("background", UNSET))

        def _parse_bleu(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        bleu = _parse_bleu(d.pop("bleu", UNSET))

        def _parse_boundary_iou(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        boundary_iou = _parse_boundary_iou(d.pop("boundary_iou", UNSET))

        def _parse_boxes(data: object) -> Union[None, Unset, list["BBox"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                boxes_type_0 = []
                _boxes_type_0 = data
                for boxes_type_0_item_data in _boxes_type_0:
                    boxes_type_0_item = BBox.from_dict(boxes_type_0_item_data)

                    boxes_type_0.append(boxes_type_0_item)

                return boxes_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["BBox"]], data)

        boxes = _parse_boxes(d.pop("boxes", UNSET))

        def _parse_classification(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        classification = _parse_classification(d.pop("classification", UNSET))

        def _parse_classification_and_localization(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        classification_and_localization = _parse_classification_and_localization(
            d.pop("classification_and_localization", UNSET)
        )

        def _parse_confidence(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        confidence = _parse_confidence(d.pop("confidence", UNSET))

        def _parse_data_error_potential(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        data_error_potential = _parse_data_error_potential(d.pop("data_error_potential", UNSET))

        def _parse_dep_mask(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        dep_mask = _parse_dep_mask(d.pop("dep_mask", UNSET))

        def _parse_drift_score(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        drift_score = _parse_drift_score(d.pop("drift_score", UNSET))

        def _parse_duplicate(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        duplicate = _parse_duplicate(d.pop("duplicate", UNSET))

        edit_relabeled = d.pop("edit_relabeled", UNSET)

        edited = d.pop("edited", UNSET)

        def _parse_generated_output(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        generated_output = _parse_generated_output(d.pop("generated_output", UNSET))

        def _parse_generated_segments(data: object) -> Union[None, Unset, list["Seq2SeqSegment"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                generated_segments_type_0 = []
                _generated_segments_type_0 = data
                for generated_segments_type_0_item_data in _generated_segments_type_0:
                    generated_segments_type_0_item = Seq2SeqSegment.from_dict(generated_segments_type_0_item_data)

                    generated_segments_type_0.append(generated_segments_type_0_item)

                return generated_segments_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["Seq2SeqSegment"]], data)

        generated_segments = _parse_generated_segments(d.pop("generated_segments", UNSET))

        def _parse_generated_uncertainty(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        generated_uncertainty = _parse_generated_uncertainty(d.pop("generated_uncertainty", UNSET))

        def _parse_ghost_span(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        ghost_span = _parse_ghost_span(d.pop("ghost_span", UNSET))

        def _parse_gold(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        gold = _parse_gold(d.pop("gold", UNSET))

        def _parse_height(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        height = _parse_height(d.pop("height", UNSET))

        def _parse_image(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        image = _parse_image(d.pop("image", UNSET))

        def _parse_input_(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        input_ = _parse_input_(d.pop("input", UNSET))

        def _parse_input_cutoff(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        input_cutoff = _parse_input_cutoff(d.pop("input_cutoff", UNSET))

        def _parse_is_drifted(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        is_drifted = _parse_is_drifted(d.pop("is_drifted", UNSET))

        def _parse_is_on_the_boundary(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        is_on_the_boundary = _parse_is_on_the_boundary(d.pop("is_on_the_boundary", UNSET))

        def _parse_localization(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        localization = _parse_localization(d.pop("localization", UNSET))

        def _parse_max_dep(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        max_dep = _parse_max_dep(d.pop("max_dep", UNSET))

        def _parse_max_dep_label(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        max_dep_label = _parse_max_dep_label(d.pop("max_dep_label", UNSET))

        def _parse_mean_iou(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        mean_iou = _parse_mean_iou(d.pop("mean_iou", UNSET))

        def _parse_meta(data: object) -> Union["DataRowMetaType0", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                meta_type_0 = DataRowMetaType0.from_dict(data)

                return meta_type_0
            except:  # noqa: E722
                pass
            return cast(Union["DataRowMetaType0", None, Unset], data)

        meta = _parse_meta(d.pop("meta", UNSET))

        def _parse_missed(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        missed = _parse_missed(d.pop("missed", UNSET))

        def _parse_missed_label(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        missed_label = _parse_missed_label(d.pop("missed_label", UNSET))

        def _parse_mltc_golds(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                mltc_golds_type_0 = cast(list[str], data)

                return mltc_golds_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        mltc_golds = _parse_mltc_golds(d.pop("mltc_golds", UNSET))

        def _parse_mltc_golds_deps(data: object) -> Union[None, Unset, list[float]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                mltc_golds_deps_type_0 = cast(list[float], data)

                return mltc_golds_deps_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[float]], data)

        mltc_golds_deps = _parse_mltc_golds_deps(d.pop("mltc_golds_deps", UNSET))

        def _parse_mltc_preds(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                mltc_preds_type_0 = cast(list[str], data)

                return mltc_preds_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        mltc_preds = _parse_mltc_preds(d.pop("mltc_preds", UNSET))

        def _parse_mltc_preds_deps(data: object) -> Union[None, Unset, list[float]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                mltc_preds_deps_type_0 = cast(list[float], data)

                return mltc_preds_deps_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[float]], data)

        mltc_preds_deps = _parse_mltc_preds_deps(d.pop("mltc_preds_deps", UNSET))

        def _parse_noise_type(data: object) -> Union[NoiseType, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                noise_type_type_0 = NoiseType(data)

                return noise_type_type_0
            except:  # noqa: E722
                pass
            return cast(Union[NoiseType, None, Unset], data)

        noise_type = _parse_noise_type(d.pop("noise_type", UNSET))

        def _parse_perplexity(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        perplexity = _parse_perplexity(d.pop("perplexity", UNSET))

        def _parse_polygons(data: object) -> Union[None, Unset, list["PolygonData"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                polygons_type_0 = []
                _polygons_type_0 = data
                for polygons_type_0_item_data in _polygons_type_0:
                    polygons_type_0_item = PolygonData.from_dict(polygons_type_0_item_data)

                    polygons_type_0.append(polygons_type_0_item)

                return polygons_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["PolygonData"]], data)

        polygons = _parse_polygons(d.pop("polygons", UNSET))

        def _parse_pred(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        pred = _parse_pred(d.pop("pred", UNSET))

        def _parse_rouge(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        rouge = _parse_rouge(d.pop("rouge", UNSET))

        def _parse_span_shift(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        span_shift = _parse_span_shift(d.pop("span_shift", UNSET))

        def _parse_spans(data: object) -> Union[None, Unset, list["Span"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                spans_type_0 = []
                _spans_type_0 = data
                for spans_type_0_item_data in _spans_type_0:
                    spans_type_0_item = Span.from_dict(spans_type_0_item_data)

                    spans_type_0.append(spans_type_0_item)

                return spans_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["Span"]], data)

        spans = _parse_spans(d.pop("spans", UNSET))

        def _parse_system_prompts(data: object) -> Union["DataRowSystemPromptsType0", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                system_prompts_type_0 = DataRowSystemPromptsType0.from_dict(data)

                return system_prompts_type_0
            except:  # noqa: E722
                pass
            return cast(Union["DataRowSystemPromptsType0", None, Unset], data)

        system_prompts = _parse_system_prompts(d.pop("system_prompts", UNSET))

        def _parse_target(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        target = _parse_target(d.pop("target", UNSET))

        def _parse_target_cutoff(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        target_cutoff = _parse_target_cutoff(d.pop("target_cutoff", UNSET))

        def _parse_target_segments(data: object) -> Union[None, Unset, list["Seq2SeqSegment"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                target_segments_type_0 = []
                _target_segments_type_0 = data
                for target_segments_type_0_item_data in _target_segments_type_0:
                    target_segments_type_0_item = Seq2SeqSegment.from_dict(target_segments_type_0_item_data)

                    target_segments_type_0.append(target_segments_type_0_item)

                return target_segments_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["Seq2SeqSegment"]], data)

        target_segments = _parse_target_segments(d.pop("target_segments", UNSET))

        def _parse_text(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        text = _parse_text(d.pop("text", UNSET))

        def _parse_total_errors(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        total_errors = _parse_total_errors(d.pop("total_errors", UNSET))

        def _parse_width(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        width = _parse_width(d.pop("width", UNSET))

        def _parse_wrong_tag(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        wrong_tag = _parse_wrong_tag(d.pop("wrong_tag", UNSET))

        def _parse_x(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        x = _parse_x(d.pop("x", UNSET))

        def _parse_y(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        y = _parse_y(d.pop("y", UNSET))

        data_row = cls(
            id=id,
            background=background,
            bleu=bleu,
            boundary_iou=boundary_iou,
            boxes=boxes,
            classification=classification,
            classification_and_localization=classification_and_localization,
            confidence=confidence,
            data_error_potential=data_error_potential,
            dep_mask=dep_mask,
            drift_score=drift_score,
            duplicate=duplicate,
            edit_relabeled=edit_relabeled,
            edited=edited,
            generated_output=generated_output,
            generated_segments=generated_segments,
            generated_uncertainty=generated_uncertainty,
            ghost_span=ghost_span,
            gold=gold,
            height=height,
            image=image,
            input_=input_,
            input_cutoff=input_cutoff,
            is_drifted=is_drifted,
            is_on_the_boundary=is_on_the_boundary,
            localization=localization,
            max_dep=max_dep,
            max_dep_label=max_dep_label,
            mean_iou=mean_iou,
            meta=meta,
            missed=missed,
            missed_label=missed_label,
            mltc_golds=mltc_golds,
            mltc_golds_deps=mltc_golds_deps,
            mltc_preds=mltc_preds,
            mltc_preds_deps=mltc_preds_deps,
            noise_type=noise_type,
            perplexity=perplexity,
            polygons=polygons,
            pred=pred,
            rouge=rouge,
            span_shift=span_shift,
            spans=spans,
            system_prompts=system_prompts,
            target=target,
            target_cutoff=target_cutoff,
            target_segments=target_segments,
            text=text,
            total_errors=total_errors,
            width=width,
            wrong_tag=wrong_tag,
            x=x,
            y=y,
        )

        data_row.additional_properties = d
        return data_row

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="EditSpan")


@_attrs_define
class EditSpan:
    """
    Attributes:
        end_index (int):
        label (str):
        start_index (int):
        id (Union[None, Unset, int]):
    """

    end_index: int
    label: str
    start_index: int
    id: Union[None, Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        end_index = self.end_index

        label = self.label

        start_index = self.start_index

        id: Union[None, Unset, int]
        if isinstance(self.id, Unset):
            id = UNSET
        else:
            id = self.id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"end_index": end_index, "label": label, "start_index": start_index})
        if id is not UNSET:
            field_dict["id"] = id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        end_index = d.pop("end_index")

        label = d.pop("label")

        start_index = d.pop("start_index")

        def _parse_id(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        id = _parse_id(d.pop("id", UNSET))

        edit_span = cls(end_index=end_index, label=label, start_index=start_index, id=id)

        edit_span.additional_properties = d
        return edit_span

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.task_type import TaskType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.edit_summary import EditSummary
    from ..models.model_metrics import ModelMetrics
    from ..models.slice_metrics import SliceMetrics


T = TypeVar("T", bound="ProjectRunSummary")


@_attrs_define
class ProjectRunSummary:
    """
    Attributes:
        avg_samples (float):
        hard_sample_pct (float):
        id (str):
        labels (list[str]):
        metrics (ModelMetrics):
        name (str):
        num_samples (int):
        slices (list['SliceMetrics']):
        task_type (TaskType): Valid task types for modeling.

            We store these as ints instead of strings because we will be looking this up in the database frequently.
        updated_at (datetime.datetime):
        data_edits (Union[Unset, list['EditSummary']]):
        hard_sample_metrics (Union['ModelMetrics', None, Unset]):
        num_spans (Union[None, Unset, int]):
        spans_per_class (Union[None, Unset, float]):
        spans_per_sample (Union[None, Unset, float]):
        task (Union[None, Unset, str]):
    """

    avg_samples: float
    hard_sample_pct: float
    id: str
    labels: list[str]
    metrics: "ModelMetrics"
    name: str
    num_samples: int
    slices: list["SliceMetrics"]
    task_type: TaskType
    updated_at: datetime.datetime
    data_edits: Union[Unset, list["EditSummary"]] = UNSET
    hard_sample_metrics: Union["ModelMetrics", None, Unset] = UNSET
    num_spans: Union[None, Unset, int] = UNSET
    spans_per_class: Union[None, Unset, float] = UNSET
    spans_per_sample: Union[None, Unset, float] = UNSET
    task: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.model_metrics import ModelMetrics

        avg_samples = self.avg_samples

        hard_sample_pct = self.hard_sample_pct

        id = self.id

        labels = self.labels

        metrics = self.metrics.to_dict()

        name = self.name

        num_samples = self.num_samples

        slices = []
        for slices_item_data in self.slices:
            slices_item = slices_item_data.to_dict()
            slices.append(slices_item)

        task_type = self.task_type.value

        updated_at = self.updated_at.isoformat()

        data_edits: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.data_edits, Unset):
            data_edits = []
            for data_edits_item_data in self.data_edits:
                data_edits_item = data_edits_item_data.to_dict()
                data_edits.append(data_edits_item)

        hard_sample_metrics: Union[None, Unset, dict[str, Any]]
        if isinstance(self.hard_sample_metrics, Unset):
            hard_sample_metrics = UNSET
        elif isinstance(self.hard_sample_metrics, ModelMetrics):
            hard_sample_metrics = self.hard_sample_metrics.to_dict()
        else:
            hard_sample_metrics = self.hard_sample_metrics

        num_spans: Union[None, Unset, int]
        if isinstance(self.num_spans, Unset):
            num_spans = UNSET
        else:
            num_spans = self.num_spans

        spans_per_class: Union[None, Unset, float]
        if isinstance(self.spans_per_class, Unset):
            spans_per_class = UNSET
        else:
            spans_per_class = self.spans_per_class

        spans_per_sample: Union[None, Unset, float]
        if isinstance(self.spans_per_sample, Unset):
            spans_per_sample = UNSET
        else:
            spans_per_sample = self.spans_per_sample

        task: Union[None, Unset, str]
        if isinstance(self.task, Unset):
            task = UNSET
        else:
            task = self.task

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "avg_samples": avg_samples,
                "hard_sample_pct": hard_sample_pct,
                "id": id,
                "labels": labels,
                "metrics": metrics,
                "name": name,
                "num_samples": num_samples,
                "slices": slices,
                "task_type": task_type,
                "updated_at": updated_at,
            }
        )
        if data_edits is not UNSET:
            field_dict["data_edits"] = data_edits
        if hard_sample_metrics is not UNSET:
            field_dict["hard_sample_metrics"] = hard_sample_metrics
        if num_spans is not UNSET:
            field_dict["num_spans"] = num_spans
        if spans_per_class is not UNSET:
            field_dict["spans_per_class"] = spans_per_class
        if spans_per_sample is not UNSET:
            field_dict["spans_per_sample"] = spans_per_sample
        if task is not UNSET:
            field_dict["task"] = task

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.edit_summary import EditSummary
        from ..models.model_metrics import ModelMetrics
        from ..models.slice_metrics import SliceMetrics

        d = src_dict.copy()
        avg_samples = d.pop("avg_samples")

        hard_sample_pct = d.pop("hard_sample_pct")

        id = d.pop("id")

        labels = cast(list[str], d.pop("labels"))

        metrics = ModelMetrics.from_dict(d.pop("metrics"))

        name = d.pop("name")

        num_samples = d.pop("num_samples")

        slices = []
        _slices = d.pop("slices")
        for slices_item_data in _slices:
            slices_item = SliceMetrics.from_dict(slices_item_data)

            slices.append(slices_item)

        task_type = TaskType(d.pop("task_type"))

        updated_at = isoparse(d.pop("updated_at"))

        data_edits = []
        _data_edits = d.pop("data_edits", UNSET)
        for data_edits_item_data in _data_edits or []:
            data_edits_item = EditSummary.from_dict(data_edits_item_data)

            data_edits.append(data_edits_item)

        def _parse_hard_sample_metrics(data: object) -> Union["ModelMetrics", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                hard_sample_metrics_type_0 = ModelMetrics.from_dict(data)

                return hard_sample_metrics_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ModelMetrics", None, Unset], data)

        hard_sample_metrics = _parse_hard_sample_metrics(d.pop("hard_sample_metrics", UNSET))

        def _parse_num_spans(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        num_spans = _parse_num_spans(d.pop("num_spans", UNSET))

        def _parse_spans_per_class(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        spans_per_class = _parse_spans_per_class(d.pop("spans_per_class", UNSET))

        def _parse_spans_per_sample(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        spans_per_sample = _parse_spans_per_sample(d.pop("spans_per_sample", UNSET))

        def _parse_task(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        task = _parse_task(d.pop("task", UNSET))

        project_run_summary = cls(
            avg_samples=avg_samples,
            hard_sample_pct=hard_sample_pct,
            id=id,
            labels=labels,
            metrics=metrics,
            name=name,
            num_samples=num_samples,
            slices=slices,
            task_type=task_type,
            updated_at=updated_at,
            data_edits=data_edits,
            hard_sample_metrics=hard_sample_metrics,
            num_spans=num_spans,
            spans_per_class=spans_per_class,
            spans_per_sample=spans_per_sample,
            task=task,
        )

        project_run_summary.additional_properties = d
        return project_run_summary

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.message import Message


T = TypeVar("T", bound="BasePromptTemplateVersionResponse")


@_attrs_define
class BasePromptTemplateVersionResponse:
    """Base response from API for a prompt template version.

    Attributes:
        id (str):
        template (Union[list['Message'], str]):
        version (int):
    """

    id: str
    template: Union[list["Message"], str]
    version: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        template: Union[list[dict[str, Any]], str]
        if isinstance(self.template, list):
            template = []
            for componentsschemas_messages_item_data in self.template:
                componentsschemas_messages_item = componentsschemas_messages_item_data.to_dict()
                template.append(componentsschemas_messages_item)

        else:
            template = self.template

        version = self.version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"id": id, "template": template, "version": version})

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.message import Message

        d = src_dict.copy()
        id = d.pop("id")

        def _parse_template(data: object) -> Union[list["Message"], str]:
            try:
                if not isinstance(data, list):
                    raise TypeError()
                template_type_1 = []
                _template_type_1 = data
                for componentsschemas_messages_item_data in _template_type_1:
                    componentsschemas_messages_item = Message.from_dict(componentsschemas_messages_item_data)

                    template_type_1.append(componentsschemas_messages_item)

                return template_type_1
            except:  # noqa: E722
                pass
            return cast(Union[list["Message"], str], data)

        template = _parse_template(d.pop("template"))

        version = d.pop("version")

        base_prompt_template_version_response = cls(id=id, template=template, version=version)

        base_prompt_template_version_response.additional_properties = d
        return base_prompt_template_version_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class TransactionLoggingMethod(str, Enum):
    API_DIRECT = "api_direct"
    JS_LANGCHAIN = "js_langchain"
    JS_LOGGER = "js_logger"
    PY_LANGCHAIN = "py_langchain"
    PY_LANGCHAIN_ASYNC = "py_langchain_async"
    PY_LOGGER = "py_logger"
    WORKFLOWS = "workflows"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class GroupAction(str, Enum):
    JOIN = "join"
    LIST_MEMBERS = "list_members"
    REQUEST_TO_JOIN = "request_to_join"
    UPDATE = "update"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.feedback_aggregate import FeedbackAggregate
    from ..models.run_metric_db_extra_type_1 import RunMetricDBExtraType1


T = TypeVar("T", bound="RunMetricDB")


@_attrs_define
class RunMetricDB:
    """
    Attributes:
        created_at (datetime.datetime):
        key (str):
        run_id (str):
        updated_at (datetime.datetime):
        epoch (Union[Unset, int]):  Default: 0.
        extra (Union['RunMetricDBExtraType1', None, Unset, list[Any]]):
        object_value (Union['FeedbackAggregate', None, Unset]):
        value (Union[None, Unset, float]):
    """

    created_at: datetime.datetime
    key: str
    run_id: str
    updated_at: datetime.datetime
    epoch: Union[Unset, int] = 0
    extra: Union["RunMetricDBExtraType1", None, Unset, list[Any]] = UNSET
    object_value: Union["FeedbackAggregate", None, Unset] = UNSET
    value: Union[None, Unset, float] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.feedback_aggregate import FeedbackAggregate
        from ..models.run_metric_db_extra_type_1 import RunMetricDBExtraType1

        created_at = self.created_at.isoformat()

        key = self.key

        run_id = self.run_id

        updated_at = self.updated_at.isoformat()

        epoch = self.epoch

        extra: Union[None, Unset, dict[str, Any], list[Any]]
        if isinstance(self.extra, Unset):
            extra = UNSET
        elif isinstance(self.extra, list):
            extra = self.extra

        elif isinstance(self.extra, RunMetricDBExtraType1):
            extra = self.extra.to_dict()
        else:
            extra = self.extra

        object_value: Union[None, Unset, dict[str, Any]]
        if isinstance(self.object_value, Unset):
            object_value = UNSET
        elif isinstance(self.object_value, FeedbackAggregate):
            object_value = self.object_value.to_dict()
        else:
            object_value = self.object_value

        value: Union[None, Unset, float]
        if isinstance(self.value, Unset):
            value = UNSET
        else:
            value = self.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"created_at": created_at, "key": key, "run_id": run_id, "updated_at": updated_at})
        if epoch is not UNSET:
            field_dict["epoch"] = epoch
        if extra is not UNSET:
            field_dict["extra"] = extra
        if object_value is not UNSET:
            field_dict["object_value"] = object_value
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.feedback_aggregate import FeedbackAggregate
        from ..models.run_metric_db_extra_type_1 import RunMetricDBExtraType1

        d = src_dict.copy()
        created_at = isoparse(d.pop("created_at"))

        key = d.pop("key")

        run_id = d.pop("run_id")

        updated_at = isoparse(d.pop("updated_at"))

        epoch = d.pop("epoch", UNSET)

        def _parse_extra(data: object) -> Union["RunMetricDBExtraType1", None, Unset, list[Any]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                extra_type_0 = cast(list[Any], data)

                return extra_type_0
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                extra_type_1 = RunMetricDBExtraType1.from_dict(data)

                return extra_type_1
            except:  # noqa: E722
                pass
            return cast(Union["RunMetricDBExtraType1", None, Unset, list[Any]], data)

        extra = _parse_extra(d.pop("extra", UNSET))

        def _parse_object_value(data: object) -> Union["FeedbackAggregate", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                object_value_type_0 = FeedbackAggregate.from_dict(data)

                return object_value_type_0
            except:  # noqa: E722
                pass
            return cast(Union["FeedbackAggregate", None, Unset], data)

        object_value = _parse_object_value(d.pop("object_value", UNSET))

        def _parse_value(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        value = _parse_value(d.pop("value", UNSET))

        run_metric_db = cls(
            created_at=created_at,
            key=key,
            run_id=run_id,
            updated_at=updated_at,
            epoch=epoch,
            extra=extra,
            object_value=object_value,
            value=value,
        )

        run_metric_db.additional_properties = d
        return run_metric_db

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="PromptGroupResponse")


@_attrs_define
class PromptGroupResponse:
    """Contains relevant data for prompt column group.

    Attributes:
        columns (list[str]):
        group_label (str):
        group_description (Union[None, Unset, str]):
        group_icon (Union[Unset, str]):  Default: 'Puzzle'.
        group_name (Union[None, Unset, str]):
    """

    columns: list[str]
    group_label: str
    group_description: Union[None, Unset, str] = UNSET
    group_icon: Union[Unset, str] = "Puzzle"
    group_name: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        columns = self.columns

        group_label = self.group_label

        group_description: Union[None, Unset, str]
        if isinstance(self.group_description, Unset):
            group_description = UNSET
        else:
            group_description = self.group_description

        group_icon = self.group_icon

        group_name: Union[None, Unset, str]
        if isinstance(self.group_name, Unset):
            group_name = UNSET
        else:
            group_name = self.group_name

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"columns": columns, "group_label": group_label})
        if group_description is not UNSET:
            field_dict["group_description"] = group_description
        if group_icon is not UNSET:
            field_dict["group_icon"] = group_icon
        if group_name is not UNSET:
            field_dict["group_name"] = group_name

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        columns = cast(list[str], d.pop("columns"))

        group_label = d.pop("group_label")

        def _parse_group_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        group_description = _parse_group_description(d.pop("group_description", UNSET))

        group_icon = d.pop("group_icon", UNSET)

        def _parse_group_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        group_name = _parse_group_name(d.pop("group_name", UNSET))

        prompt_group_response = cls(
            columns=columns,
            group_label=group_label,
            group_description=group_description,
            group_icon=group_icon,
            group_name=group_name,
        )

        prompt_group_response.additional_properties = d
        return prompt_group_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.split import Split
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.filter_params import FilterParams


T = TypeVar("T", bound="SummaryIDRequest")


@_attrs_define
class SummaryIDRequest:
    """
    Attributes:
        compare_to (Union[None, Split, Unset]):
        filter_params (Union[Unset, FilterParams]):
        hard_easy_threshold (Union[Unset, bool]):  Default: False.
        include_emb (Union[Unset, bool]):  Default: True.
        map_threshold (Union[Unset, float]):  Default: 0.5.
        meta_cols (Union[None, Unset, list[str]]):
        page_num (Union[Unset, int]):  Default: 0.
        sort_ascending (Union[Unset, bool]):  Default: False.
        sort_by (Union[None, Unset, str]):
        sort_by_id_list (Union[Unset, bool]):  Default: False.
        task (Union[None, Unset, str]):
    """

    compare_to: Union[None, Split, Unset] = UNSET
    filter_params: Union[Unset, "FilterParams"] = UNSET
    hard_easy_threshold: Union[Unset, bool] = False
    include_emb: Union[Unset, bool] = True
    map_threshold: Union[Unset, float] = 0.5
    meta_cols: Union[None, Unset, list[str]] = UNSET
    page_num: Union[Unset, int] = 0
    sort_ascending: Union[Unset, bool] = False
    sort_by: Union[None, Unset, str] = UNSET
    sort_by_id_list: Union[Unset, bool] = False
    task: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        compare_to: Union[None, Unset, str]
        if isinstance(self.compare_to, Unset):
            compare_to = UNSET
        elif isinstance(self.compare_to, Split):
            compare_to = self.compare_to.value
        else:
            compare_to = self.compare_to

        filter_params: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.filter_params, Unset):
            filter_params = self.filter_params.to_dict()

        hard_easy_threshold = self.hard_easy_threshold

        include_emb = self.include_emb

        map_threshold = self.map_threshold

        meta_cols: Union[None, Unset, list[str]]
        if isinstance(self.meta_cols, Unset):
            meta_cols = UNSET
        elif isinstance(self.meta_cols, list):
            meta_cols = self.meta_cols

        else:
            meta_cols = self.meta_cols

        page_num = self.page_num

        sort_ascending = self.sort_ascending

        sort_by: Union[None, Unset, str]
        if isinstance(self.sort_by, Unset):
            sort_by = UNSET
        else:
            sort_by = self.sort_by

        sort_by_id_list = self.sort_by_id_list

        task: Union[None, Unset, str]
        if isinstance(self.task, Unset):
            task = UNSET
        else:
            task = self.task

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if compare_to is not UNSET:
            field_dict["compare_to"] = compare_to
        if filter_params is not UNSET:
            field_dict["filter_params"] = filter_params
        if hard_easy_threshold is not UNSET:
            field_dict["hard_easy_threshold"] = hard_easy_threshold
        if include_emb is not UNSET:
            field_dict["include_emb"] = include_emb
        if map_threshold is not UNSET:
            field_dict["map_threshold"] = map_threshold
        if meta_cols is not UNSET:
            field_dict["meta_cols"] = meta_cols
        if page_num is not UNSET:
            field_dict["page_num"] = page_num
        if sort_ascending is not UNSET:
            field_dict["sort_ascending"] = sort_ascending
        if sort_by is not UNSET:
            field_dict["sort_by"] = sort_by
        if sort_by_id_list is not UNSET:
            field_dict["sort_by_id_list"] = sort_by_id_list
        if task is not UNSET:
            field_dict["task"] = task

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.filter_params import FilterParams

        d = src_dict.copy()

        def _parse_compare_to(data: object) -> Union[None, Split, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                compare_to_type_0 = Split(data)

                return compare_to_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Split, Unset], data)

        compare_to = _parse_compare_to(d.pop("compare_to", UNSET))

        _filter_params = d.pop("filter_params", UNSET)
        filter_params: Union[Unset, FilterParams]
        if isinstance(_filter_params, Unset):
            filter_params = UNSET
        else:
            filter_params = FilterParams.from_dict(_filter_params)

        hard_easy_threshold = d.pop("hard_easy_threshold", UNSET)

        include_emb = d.pop("include_emb", UNSET)

        map_threshold = d.pop("map_threshold", UNSET)

        def _parse_meta_cols(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                meta_cols_type_0 = cast(list[str], data)

                return meta_cols_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        meta_cols = _parse_meta_cols(d.pop("meta_cols", UNSET))

        page_num = d.pop("page_num", UNSET)

        sort_ascending = d.pop("sort_ascending", UNSET)

        def _parse_sort_by(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        sort_by = _parse_sort_by(d.pop("sort_by", UNSET))

        sort_by_id_list = d.pop("sort_by_id_list", UNSET)

        def _parse_task(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        task = _parse_task(d.pop("task", UNSET))

        summary_id_request = cls(
            compare_to=compare_to,
            filter_params=filter_params,
            hard_easy_threshold=hard_easy_threshold,
            include_emb=include_emb,
            map_threshold=map_threshold,
            meta_cols=meta_cols,
            page_num=page_num,
            sort_ascending=sort_ascending,
            sort_by=sort_by,
            sort_by_id_list=sort_by_id_list,
            task=task,
        )

        summary_id_request.additional_properties = d
        return summary_id_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.document_metadata import DocumentMetadata


T = TypeVar("T", bound="Document")


@_attrs_define
class Document:
    """
    Attributes:
        page_content (str): Content of the document.
        metadata (Union[Unset, DocumentMetadata]):
    """

    page_content: str
    metadata: Union[Unset, "DocumentMetadata"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        page_content = self.page_content

        metadata: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update({"page_content": page_content})
        if metadata is not UNSET:
            field_dict["metadata"] = metadata

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.document_metadata import DocumentMetadata

        d = src_dict.copy()
        page_content = d.pop("page_content")

        _metadata = d.pop("metadata", UNSET)
        metadata: Union[Unset, DocumentMetadata]
        if isinstance(_metadata, Unset):
            metadata = UNSET
        else:
            metadata = DocumentMetadata.from_dict(_metadata)

        document = cls(page_content=page_content, metadata=metadata)

        return document



from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="WorkflowCountResponse")


@_attrs_define
class WorkflowCountResponse:
    """
    Attributes:
        count (int):
        max_rows (Union[Unset, int]):  Default: 512.
        max_rows_exceeded (Union[Unset, bool]):  Default: False.
    """

    count: int
    max_rows: Union[Unset, int] = 512
    max_rows_exceeded: Union[Unset, bool] = False
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        count = self.count

        max_rows = self.max_rows

        max_rows_exceeded = self.max_rows_exceeded

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"count": count})
        if max_rows is not UNSET:
            field_dict["max_rows"] = max_rows
        if max_rows_exceeded is not UNSET:
            field_dict["max_rows_exceeded"] = max_rows_exceeded

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        count = d.pop("count")

        max_rows = d.pop("max_rows", UNSET)

        max_rows_exceeded = d.pop("max_rows_exceeded", UNSET)

        workflow_count_response = cls(count=count, max_rows=max_rows, max_rows_exceeded=max_rows_exceeded)

        workflow_count_response.additional_properties = d
        return workflow_count_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.agentic_workflow_success_scorer import AgenticWorkflowSuccessScorer
    from ..models.bleu_scorer import BleuScorer
    from ..models.chain_row import ChainRow
    from ..models.chunk_attribution_utilization_scorer import ChunkAttributionUtilizationScorer
    from ..models.completeness_scorer import CompletenessScorer
    from ..models.context_adherence_scorer import ContextAdherenceScorer
    from ..models.context_relevance_scorer import ContextRelevanceScorer
    from ..models.correctness_scorer import CorrectnessScorer
    from ..models.customized_agentic_workflow_success_gpt_scorer import CustomizedAgenticWorkflowSuccessGPTScorer
    from ..models.customized_chunk_attribution_utilization_gpt_scorer import (
        CustomizedChunkAttributionUtilizationGPTScorer,
    )
    from ..models.customized_completeness_gpt_scorer import CustomizedCompletenessGPTScorer
    from ..models.customized_factuality_gpt_scorer import CustomizedFactualityGPTScorer
    from ..models.customized_ground_truth_adherence_gpt_scorer import CustomizedGroundTruthAdherenceGPTScorer
    from ..models.customized_groundedness_gpt_scorer import CustomizedGroundednessGPTScorer
    from ..models.customized_instruction_adherence_gpt_scorer import CustomizedInstructionAdherenceGPTScorer
    from ..models.customized_tool_error_rate_gpt_scorer import CustomizedToolErrorRateGPTScorer
    from ..models.customized_tool_selection_quality_gpt_scorer import CustomizedToolSelectionQualityGPTScorer
    from ..models.generated_scorer_config import GeneratedScorerConfig
    from ..models.ground_truth_adherence_scorer import GroundTruthAdherenceScorer
    from ..models.input_pii_scorer import InputPIIScorer
    from ..models.input_sexist_scorer import InputSexistScorer
    from ..models.input_tone_scorer import InputToneScorer
    from ..models.input_toxicity_scorer import InputToxicityScorer
    from ..models.instruction_adherence_scorer import InstructionAdherenceScorer
    from ..models.output_pii_scorer import OutputPIIScorer
    from ..models.output_sexist_scorer import OutputSexistScorer
    from ..models.output_tone_scorer import OutputToneScorer
    from ..models.output_toxicity_scorer import OutputToxicityScorer
    from ..models.prompt_injection_scorer import PromptInjectionScorer
    from ..models.prompt_perplexity_scorer import PromptPerplexityScorer
    from ..models.registered_scorer import RegisteredScorer
    from ..models.rouge_scorer import RougeScorer
    from ..models.scorers_configuration import ScorersConfiguration
    from ..models.tool_error_rate_scorer import ToolErrorRateScorer
    from ..models.tool_selection_quality_scorer import ToolSelectionQualityScorer
    from ..models.uncertainty_scorer import UncertaintyScorer


T = TypeVar("T", bound="PromptChainIngestRequest")


@_attrs_define
class PromptChainIngestRequest:
    """
    Attributes:
        generated_scorers (Union[None, Unset, list['GeneratedScorerConfig']]):
        prompt_customized_scorers_configuration (Union[None, Unset,
            list[Union['CustomizedAgenticWorkflowSuccessGPTScorer', 'CustomizedChunkAttributionUtilizationGPTScorer',
            'CustomizedCompletenessGPTScorer', 'CustomizedFactualityGPTScorer', 'CustomizedGroundTruthAdherenceGPTScorer',
            'CustomizedGroundednessGPTScorer', 'CustomizedInstructionAdherenceGPTScorer',
            'CustomizedToolErrorRateGPTScorer', 'CustomizedToolSelectionQualityGPTScorer']]]):
        prompt_registered_scorers_configuration (Union[None, Unset, list['RegisteredScorer']]):
        prompt_scorers_configuration (Union['ScorersConfiguration', None, Unset]):
        rows (Union[Unset, list['ChainRow']]):
        scorers (Union[Unset, list[Union['AgenticWorkflowSuccessScorer', 'BleuScorer',
            'ChunkAttributionUtilizationScorer', 'CompletenessScorer', 'ContextAdherenceScorer', 'ContextRelevanceScorer',
            'CorrectnessScorer', 'GroundTruthAdherenceScorer', 'InputPIIScorer', 'InputSexistScorer', 'InputToneScorer',
            'InputToxicityScorer', 'InstructionAdherenceScorer', 'OutputPIIScorer', 'OutputSexistScorer',
            'OutputToneScorer', 'OutputToxicityScorer', 'PromptInjectionScorer', 'PromptPerplexityScorer', 'RougeScorer',
            'ToolErrorRateScorer', 'ToolSelectionQualityScorer', 'UncertaintyScorer']]]):
    """

    generated_scorers: Union[None, Unset, list["GeneratedScorerConfig"]] = UNSET
    prompt_customized_scorers_configuration: Union[
        None,
        Unset,
        list[
            Union[
                "CustomizedAgenticWorkflowSuccessGPTScorer",
                "CustomizedChunkAttributionUtilizationGPTScorer",
                "CustomizedCompletenessGPTScorer",
                "CustomizedFactualityGPTScorer",
                "CustomizedGroundTruthAdherenceGPTScorer",
                "CustomizedGroundednessGPTScorer",
                "CustomizedInstructionAdherenceGPTScorer",
                "CustomizedToolErrorRateGPTScorer",
                "CustomizedToolSelectionQualityGPTScorer",
            ]
        ],
    ] = UNSET
    prompt_registered_scorers_configuration: Union[None, Unset, list["RegisteredScorer"]] = UNSET
    prompt_scorers_configuration: Union["ScorersConfiguration", None, Unset] = UNSET
    rows: Union[Unset, list["ChainRow"]] = UNSET
    scorers: Union[
        Unset,
        list[
            Union[
                "AgenticWorkflowSuccessScorer",
                "BleuScorer",
                "ChunkAttributionUtilizationScorer",
                "CompletenessScorer",
                "ContextAdherenceScorer",
                "ContextRelevanceScorer",
                "CorrectnessScorer",
                "GroundTruthAdherenceScorer",
                "InputPIIScorer",
                "InputSexistScorer",
                "InputToneScorer",
                "InputToxicityScorer",
                "InstructionAdherenceScorer",
                "OutputPIIScorer",
                "OutputSexistScorer",
                "OutputToneScorer",
                "OutputToxicityScorer",
                "PromptInjectionScorer",
                "PromptPerplexityScorer",
                "RougeScorer",
                "ToolErrorRateScorer",
                "ToolSelectionQualityScorer",
                "UncertaintyScorer",
            ]
        ],
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.agentic_workflow_success_scorer import AgenticWorkflowSuccessScorer
        from ..models.bleu_scorer import BleuScorer
        from ..models.chunk_attribution_utilization_scorer import ChunkAttributionUtilizationScorer
        from ..models.completeness_scorer import CompletenessScorer
        from ..models.context_adherence_scorer import ContextAdherenceScorer
        from ..models.context_relevance_scorer import ContextRelevanceScorer
        from ..models.correctness_scorer import CorrectnessScorer
        from ..models.customized_agentic_workflow_success_gpt_scorer import CustomizedAgenticWorkflowSuccessGPTScorer
        from ..models.customized_chunk_attribution_utilization_gpt_scorer import (
            CustomizedChunkAttributionUtilizationGPTScorer,
        )
        from ..models.customized_completeness_gpt_scorer import CustomizedCompletenessGPTScorer
        from ..models.customized_factuality_gpt_scorer import CustomizedFactualityGPTScorer
        from ..models.customized_ground_truth_adherence_gpt_scorer import CustomizedGroundTruthAdherenceGPTScorer
        from ..models.customized_groundedness_gpt_scorer import CustomizedGroundednessGPTScorer
        from ..models.customized_instruction_adherence_gpt_scorer import CustomizedInstructionAdherenceGPTScorer
        from ..models.customized_tool_selection_quality_gpt_scorer import CustomizedToolSelectionQualityGPTScorer
        from ..models.ground_truth_adherence_scorer import GroundTruthAdherenceScorer
        from ..models.input_pii_scorer import InputPIIScorer
        from ..models.input_sexist_scorer import InputSexistScorer
        from ..models.input_tone_scorer import InputToneScorer
        from ..models.input_toxicity_scorer import InputToxicityScorer
        from ..models.instruction_adherence_scorer import InstructionAdherenceScorer
        from ..models.output_pii_scorer import OutputPIIScorer
        from ..models.output_sexist_scorer import OutputSexistScorer
        from ..models.output_tone_scorer import OutputToneScorer
        from ..models.output_toxicity_scorer import OutputToxicityScorer
        from ..models.prompt_injection_scorer import PromptInjectionScorer
        from ..models.prompt_perplexity_scorer import PromptPerplexityScorer
        from ..models.rouge_scorer import RougeScorer
        from ..models.scorers_configuration import ScorersConfiguration
        from ..models.tool_error_rate_scorer import ToolErrorRateScorer
        from ..models.tool_selection_quality_scorer import ToolSelectionQualityScorer

        generated_scorers: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.generated_scorers, Unset):
            generated_scorers = UNSET
        elif isinstance(self.generated_scorers, list):
            generated_scorers = []
            for generated_scorers_type_0_item_data in self.generated_scorers:
                generated_scorers_type_0_item = generated_scorers_type_0_item_data.to_dict()
                generated_scorers.append(generated_scorers_type_0_item)

        else:
            generated_scorers = self.generated_scorers

        prompt_customized_scorers_configuration: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.prompt_customized_scorers_configuration, Unset):
            prompt_customized_scorers_configuration = UNSET
        elif isinstance(self.prompt_customized_scorers_configuration, list):
            prompt_customized_scorers_configuration = []
            for (
                prompt_customized_scorers_configuration_type_0_item_data
            ) in self.prompt_customized_scorers_configuration:
                prompt_customized_scorers_configuration_type_0_item: dict[str, Any]
                if isinstance(
                    prompt_customized_scorers_configuration_type_0_item_data, CustomizedAgenticWorkflowSuccessGPTScorer
                ):
                    prompt_customized_scorers_configuration_type_0_item = (
                        prompt_customized_scorers_configuration_type_0_item_data.to_dict()
                    )
                elif isinstance(
                    prompt_customized_scorers_configuration_type_0_item_data,
                    CustomizedChunkAttributionUtilizationGPTScorer,
                ):
                    prompt_customized_scorers_configuration_type_0_item = (
                        prompt_customized_scorers_configuration_type_0_item_data.to_dict()
                    )
                elif isinstance(
                    prompt_customized_scorers_configuration_type_0_item_data, CustomizedCompletenessGPTScorer
                ):
                    prompt_customized_scorers_configuration_type_0_item = (
                        prompt_customized_scorers_configuration_type_0_item_data.to_dict()
                    )
                elif isinstance(
                    prompt_customized_scorers_configuration_type_0_item_data, CustomizedFactualityGPTScorer
                ):
                    prompt_customized_scorers_configuration_type_0_item = (
                        prompt_customized_scorers_configuration_type_0_item_data.to_dict()
                    )
                elif isinstance(
                    prompt_customized_scorers_configuration_type_0_item_data, CustomizedGroundednessGPTScorer
                ):
                    prompt_customized_scorers_configuration_type_0_item = (
                        prompt_customized_scorers_configuration_type_0_item_data.to_dict()
                    )
                elif isinstance(
                    prompt_customized_scorers_configuration_type_0_item_data, CustomizedInstructionAdherenceGPTScorer
                ):
                    prompt_customized_scorers_configuration_type_0_item = (
                        prompt_customized_scorers_configuration_type_0_item_data.to_dict()
                    )
                elif isinstance(
                    prompt_customized_scorers_configuration_type_0_item_data, CustomizedGroundTruthAdherenceGPTScorer
                ):
                    prompt_customized_scorers_configuration_type_0_item = (
                        prompt_customized_scorers_configuration_type_0_item_data.to_dict()
                    )
                elif isinstance(
                    prompt_customized_scorers_configuration_type_0_item_data, CustomizedToolSelectionQualityGPTScorer
                ):
                    prompt_customized_scorers_configuration_type_0_item = (
                        prompt_customized_scorers_configuration_type_0_item_data.to_dict()
                    )
                else:
                    prompt_customized_scorers_configuration_type_0_item = (
                        prompt_customized_scorers_configuration_type_0_item_data.to_dict()
                    )

                prompt_customized_scorers_configuration.append(prompt_customized_scorers_configuration_type_0_item)

        else:
            prompt_customized_scorers_configuration = self.prompt_customized_scorers_configuration

        prompt_registered_scorers_configuration: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.prompt_registered_scorers_configuration, Unset):
            prompt_registered_scorers_configuration = UNSET
        elif isinstance(self.prompt_registered_scorers_configuration, list):
            prompt_registered_scorers_configuration = []
            for (
                prompt_registered_scorers_configuration_type_0_item_data
            ) in self.prompt_registered_scorers_configuration:
                prompt_registered_scorers_configuration_type_0_item = (
                    prompt_registered_scorers_configuration_type_0_item_data.to_dict()
                )
                prompt_registered_scorers_configuration.append(prompt_registered_scorers_configuration_type_0_item)

        else:
            prompt_registered_scorers_configuration = self.prompt_registered_scorers_configuration

        prompt_scorers_configuration: Union[None, Unset, dict[str, Any]]
        if isinstance(self.prompt_scorers_configuration, Unset):
            prompt_scorers_configuration = UNSET
        elif isinstance(self.prompt_scorers_configuration, ScorersConfiguration):
            prompt_scorers_configuration = self.prompt_scorers_configuration.to_dict()
        else:
            prompt_scorers_configuration = self.prompt_scorers_configuration

        rows: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.rows, Unset):
            rows = []
            for rows_item_data in self.rows:
                rows_item = rows_item_data.to_dict()
                rows.append(rows_item)

        scorers: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.scorers, Unset):
            scorers = []
            for scorers_item_data in self.scorers:
                scorers_item: dict[str, Any]
                if isinstance(scorers_item_data, AgenticWorkflowSuccessScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, BleuScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, ChunkAttributionUtilizationScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, CompletenessScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, ContextAdherenceScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, ContextRelevanceScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, CorrectnessScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, GroundTruthAdherenceScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, InputPIIScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, InputSexistScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, InputToneScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, InputToxicityScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, InstructionAdherenceScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, OutputPIIScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, OutputSexistScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, OutputToneScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, OutputToxicityScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, PromptInjectionScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, PromptPerplexityScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, RougeScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, ToolErrorRateScorer):
                    scorers_item = scorers_item_data.to_dict()
                elif isinstance(scorers_item_data, ToolSelectionQualityScorer):
                    scorers_item = scorers_item_data.to_dict()
                else:
                    scorers_item = scorers_item_data.to_dict()

                scorers.append(scorers_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if generated_scorers is not UNSET:
            field_dict["generated_scorers"] = generated_scorers
        if prompt_customized_scorers_configuration is not UNSET:
            field_dict["prompt_customized_scorers_configuration"] = prompt_customized_scorers_configuration
        if prompt_registered_scorers_configuration is not UNSET:
            field_dict["prompt_registered_scorers_configuration"] = prompt_registered_scorers_configuration
        if prompt_scorers_configuration is not UNSET:
            field_dict["prompt_scorers_configuration"] = prompt_scorers_configuration
        if rows is not UNSET:
            field_dict["rows"] = rows
        if scorers is not UNSET:
            field_dict["scorers"] = scorers

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.agentic_workflow_success_scorer import AgenticWorkflowSuccessScorer
        from ..models.bleu_scorer import BleuScorer
        from ..models.chain_row import ChainRow
        from ..models.chunk_attribution_utilization_scorer import ChunkAttributionUtilizationScorer
        from ..models.completeness_scorer import CompletenessScorer
        from ..models.context_adherence_scorer import ContextAdherenceScorer
        from ..models.context_relevance_scorer import ContextRelevanceScorer
        from ..models.correctness_scorer import CorrectnessScorer
        from ..models.customized_agentic_workflow_success_gpt_scorer import CustomizedAgenticWorkflowSuccessGPTScorer
        from ..models.customized_chunk_attribution_utilization_gpt_scorer import (
            CustomizedChunkAttributionUtilizationGPTScorer,
        )
        from ..models.customized_completeness_gpt_scorer import CustomizedCompletenessGPTScorer
        from ..models.customized_factuality_gpt_scorer import CustomizedFactualityGPTScorer
        from ..models.customized_ground_truth_adherence_gpt_scorer import CustomizedGroundTruthAdherenceGPTScorer
        from ..models.customized_groundedness_gpt_scorer import CustomizedGroundednessGPTScorer
        from ..models.customized_instruction_adherence_gpt_scorer import CustomizedInstructionAdherenceGPTScorer
        from ..models.customized_tool_error_rate_gpt_scorer import CustomizedToolErrorRateGPTScorer
        from ..models.customized_tool_selection_quality_gpt_scorer import CustomizedToolSelectionQualityGPTScorer
        from ..models.generated_scorer_config import GeneratedScorerConfig
        from ..models.ground_truth_adherence_scorer import GroundTruthAdherenceScorer
        from ..models.input_pii_scorer import InputPIIScorer
        from ..models.input_sexist_scorer import InputSexistScorer
        from ..models.input_tone_scorer import InputToneScorer
        from ..models.input_toxicity_scorer import InputToxicityScorer
        from ..models.instruction_adherence_scorer import InstructionAdherenceScorer
        from ..models.output_pii_scorer import OutputPIIScorer
        from ..models.output_sexist_scorer import OutputSexistScorer
        from ..models.output_tone_scorer import OutputToneScorer
        from ..models.output_toxicity_scorer import OutputToxicityScorer
        from ..models.prompt_injection_scorer import PromptInjectionScorer
        from ..models.prompt_perplexity_scorer import PromptPerplexityScorer
        from ..models.registered_scorer import RegisteredScorer
        from ..models.rouge_scorer import RougeScorer
        from ..models.scorers_configuration import ScorersConfiguration
        from ..models.tool_error_rate_scorer import ToolErrorRateScorer
        from ..models.tool_selection_quality_scorer import ToolSelectionQualityScorer
        from ..models.uncertainty_scorer import UncertaintyScorer

        d = src_dict.copy()

        def _parse_generated_scorers(data: object) -> Union[None, Unset, list["GeneratedScorerConfig"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                generated_scorers_type_0 = []
                _generated_scorers_type_0 = data
                for generated_scorers_type_0_item_data in _generated_scorers_type_0:
                    generated_scorers_type_0_item = GeneratedScorerConfig.from_dict(generated_scorers_type_0_item_data)

                    generated_scorers_type_0.append(generated_scorers_type_0_item)

                return generated_scorers_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["GeneratedScorerConfig"]], data)

        generated_scorers = _parse_generated_scorers(d.pop("generated_scorers", UNSET))

        def _parse_prompt_customized_scorers_configuration(
            data: object,
        ) -> Union[
            None,
            Unset,
            list[
                Union[
                    "CustomizedAgenticWorkflowSuccessGPTScorer",
                    "CustomizedChunkAttributionUtilizationGPTScorer",
                    "CustomizedCompletenessGPTScorer",
                    "CustomizedFactualityGPTScorer",
                    "CustomizedGroundTruthAdherenceGPTScorer",
                    "CustomizedGroundednessGPTScorer",
                    "CustomizedInstructionAdherenceGPTScorer",
                    "CustomizedToolErrorRateGPTScorer",
                    "CustomizedToolSelectionQualityGPTScorer",
                ]
            ],
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                prompt_customized_scorers_configuration_type_0 = []
                _prompt_customized_scorers_configuration_type_0 = data
                for (
                    prompt_customized_scorers_configuration_type_0_item_data
                ) in _prompt_customized_scorers_configuration_type_0:

                    def _parse_prompt_customized_scorers_configuration_type_0_item(
                        data: object,
                    ) -> Union[
                        "CustomizedAgenticWorkflowSuccessGPTScorer",
                        "CustomizedChunkAttributionUtilizationGPTScorer",
                        "CustomizedCompletenessGPTScorer",
                        "CustomizedFactualityGPTScorer",
                        "CustomizedGroundTruthAdherenceGPTScorer",
                        "CustomizedGroundednessGPTScorer",
                        "CustomizedInstructionAdherenceGPTScorer",
                        "CustomizedToolErrorRateGPTScorer",
                        "CustomizedToolSelectionQualityGPTScorer",
                    ]:
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            prompt_customized_scorers_configuration_type_0_item_type_0 = (
                                CustomizedAgenticWorkflowSuccessGPTScorer.from_dict(data)
                            )

                            return prompt_customized_scorers_configuration_type_0_item_type_0
                        except:  # noqa: E722
                            pass
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            prompt_customized_scorers_configuration_type_0_item_type_1 = (
                                CustomizedChunkAttributionUtilizationGPTScorer.from_dict(data)
                            )

                            return prompt_customized_scorers_configuration_type_0_item_type_1
                        except:  # noqa: E722
                            pass
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            prompt_customized_scorers_configuration_type_0_item_type_2 = (
                                CustomizedCompletenessGPTScorer.from_dict(data)
                            )

                            return prompt_customized_scorers_configuration_type_0_item_type_2
                        except:  # noqa: E722
                            pass
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            prompt_customized_scorers_configuration_type_0_item_type_3 = (
                                CustomizedFactualityGPTScorer.from_dict(data)
                            )

                            return prompt_customized_scorers_configuration_type_0_item_type_3
                        except:  # noqa: E722
                            pass
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            prompt_customized_scorers_configuration_type_0_item_type_4 = (
                                CustomizedGroundednessGPTScorer.from_dict(data)
                            )

                            return prompt_customized_scorers_configuration_type_0_item_type_4
                        except:  # noqa: E722
                            pass
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            prompt_customized_scorers_configuration_type_0_item_type_5 = (
                                CustomizedInstructionAdherenceGPTScorer.from_dict(data)
                            )

                            return prompt_customized_scorers_configuration_type_0_item_type_5
                        except:  # noqa: E722
                            pass
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            prompt_customized_scorers_configuration_type_0_item_type_6 = (
                                CustomizedGroundTruthAdherenceGPTScorer.from_dict(data)
                            )

                            return prompt_customized_scorers_configuration_type_0_item_type_6
                        except:  # noqa: E722
                            pass
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            prompt_customized_scorers_configuration_type_0_item_type_7 = (
                                CustomizedToolSelectionQualityGPTScorer.from_dict(data)
                            )

                            return prompt_customized_scorers_configuration_type_0_item_type_7
                        except:  # noqa: E722
                            pass
                        if not isinstance(data, dict):
                            raise TypeError()
                        prompt_customized_scorers_configuration_type_0_item_type_8 = (
                            CustomizedToolErrorRateGPTScorer.from_dict(data)
                        )

                        return prompt_customized_scorers_configuration_type_0_item_type_8

                    prompt_customized_scorers_configuration_type_0_item = (
                        _parse_prompt_customized_scorers_configuration_type_0_item(
                            prompt_customized_scorers_configuration_type_0_item_data
                        )
                    )

                    prompt_customized_scorers_configuration_type_0.append(
                        prompt_customized_scorers_configuration_type_0_item
                    )

                return prompt_customized_scorers_configuration_type_0
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    None,
                    Unset,
                    list[
                        Union[
                            "CustomizedAgenticWorkflowSuccessGPTScorer",
                            "CustomizedChunkAttributionUtilizationGPTScorer",
                            "CustomizedCompletenessGPTScorer",
                            "CustomizedFactualityGPTScorer",
                            "CustomizedGroundTruthAdherenceGPTScorer",
                            "CustomizedGroundednessGPTScorer",
                            "CustomizedInstructionAdherenceGPTScorer",
                            "CustomizedToolErrorRateGPTScorer",
                            "CustomizedToolSelectionQualityGPTScorer",
                        ]
                    ],
                ],
                data,
            )

        prompt_customized_scorers_configuration = _parse_prompt_customized_scorers_configuration(
            d.pop("prompt_customized_scorers_configuration", UNSET)
        )

        def _parse_prompt_registered_scorers_configuration(
            data: object,
        ) -> Union[None, Unset, list["RegisteredScorer"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                prompt_registered_scorers_configuration_type_0 = []
                _prompt_registered_scorers_configuration_type_0 = data
                for (
                    prompt_registered_scorers_configuration_type_0_item_data
                ) in _prompt_registered_scorers_configuration_type_0:
                    prompt_registered_scorers_configuration_type_0_item = RegisteredScorer.from_dict(
                        prompt_registered_scorers_configuration_type_0_item_data
                    )

                    prompt_registered_scorers_configuration_type_0.append(
                        prompt_registered_scorers_configuration_type_0_item
                    )

                return prompt_registered_scorers_configuration_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["RegisteredScorer"]], data)

        prompt_registered_scorers_configuration = _parse_prompt_registered_scorers_configuration(
            d.pop("prompt_registered_scorers_configuration", UNSET)
        )

        def _parse_prompt_scorers_configuration(data: object) -> Union["ScorersConfiguration", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                prompt_scorers_configuration_type_0 = ScorersConfiguration.from_dict(data)

                return prompt_scorers_configuration_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ScorersConfiguration", None, Unset], data)

        prompt_scorers_configuration = _parse_prompt_scorers_configuration(d.pop("prompt_scorers_configuration", UNSET))

        rows = []
        _rows = d.pop("rows", UNSET)
        for rows_item_data in _rows or []:
            rows_item = ChainRow.from_dict(rows_item_data)

            rows.append(rows_item)

        scorers = []
        _scorers = d.pop("scorers", UNSET)
        for scorers_item_data in _scorers or []:

            def _parse_scorers_item(
                data: object,
            ) -> Union[
                "AgenticWorkflowSuccessScorer",
                "BleuScorer",
                "ChunkAttributionUtilizationScorer",
                "CompletenessScorer",
                "ContextAdherenceScorer",
                "ContextRelevanceScorer",
                "CorrectnessScorer",
                "GroundTruthAdherenceScorer",
                "InputPIIScorer",
                "InputSexistScorer",
                "InputToneScorer",
                "InputToxicityScorer",
                "InstructionAdherenceScorer",
                "OutputPIIScorer",
                "OutputSexistScorer",
                "OutputToneScorer",
                "OutputToxicityScorer",
                "PromptInjectionScorer",
                "PromptPerplexityScorer",
                "RougeScorer",
                "ToolErrorRateScorer",
                "ToolSelectionQualityScorer",
                "UncertaintyScorer",
            ]:
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_0 = AgenticWorkflowSuccessScorer.from_dict(data)

                    return scorers_item_type_0
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_1 = BleuScorer.from_dict(data)

                    return scorers_item_type_1
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_2 = ChunkAttributionUtilizationScorer.from_dict(data)

                    return scorers_item_type_2
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_3 = CompletenessScorer.from_dict(data)

                    return scorers_item_type_3
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_4 = ContextAdherenceScorer.from_dict(data)

                    return scorers_item_type_4
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_5 = ContextRelevanceScorer.from_dict(data)

                    return scorers_item_type_5
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_6 = CorrectnessScorer.from_dict(data)

                    return scorers_item_type_6
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_7 = GroundTruthAdherenceScorer.from_dict(data)

                    return scorers_item_type_7
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_8 = InputPIIScorer.from_dict(data)

                    return scorers_item_type_8
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_9 = InputSexistScorer.from_dict(data)

                    return scorers_item_type_9
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_10 = InputToneScorer.from_dict(data)

                    return scorers_item_type_10
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_11 = InputToxicityScorer.from_dict(data)

                    return scorers_item_type_11
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_12 = InstructionAdherenceScorer.from_dict(data)

                    return scorers_item_type_12
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_13 = OutputPIIScorer.from_dict(data)

                    return scorers_item_type_13
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_14 = OutputSexistScorer.from_dict(data)

                    return scorers_item_type_14
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_15 = OutputToneScorer.from_dict(data)

                    return scorers_item_type_15
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_16 = OutputToxicityScorer.from_dict(data)

                    return scorers_item_type_16
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_17 = PromptInjectionScorer.from_dict(data)

                    return scorers_item_type_17
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_18 = PromptPerplexityScorer.from_dict(data)

                    return scorers_item_type_18
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_19 = RougeScorer.from_dict(data)

                    return scorers_item_type_19
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_20 = ToolErrorRateScorer.from_dict(data)

                    return scorers_item_type_20
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    scorers_item_type_21 = ToolSelectionQualityScorer.from_dict(data)

                    return scorers_item_type_21
                except:  # noqa: E722
                    pass
                if not isinstance(data, dict):
                    raise TypeError()
                scorers_item_type_22 = UncertaintyScorer.from_dict(data)

                return scorers_item_type_22

            scorers_item = _parse_scorers_item(scorers_item_data)

            scorers.append(scorers_item)

        prompt_chain_ingest_request = cls(
            generated_scorers=generated_scorers,
            prompt_customized_scorers_configuration=prompt_customized_scorers_configuration,
            prompt_registered_scorers_configuration=prompt_registered_scorers_configuration,
            prompt_scorers_configuration=prompt_scorers_configuration,
            rows=rows,
            scorers=scorers,
        )

        prompt_chain_ingest_request.additional_properties = d
        return prompt_chain_ingest_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
